@@ -8,7 +8,7 @@ Created on Wed Mar 15 23:01:06 2023
 """
 import numpy  as  np
 from   cffi  import FFI
-import PyMsOfa  as  sf
+import PyMsOfa.cffi  as  sf
  
  
 def   line():
