@@ -1,7 +1,7 @@
 import numpy  as  np
 import numpy.ctypeslib  as  nt
-import PyMsOfa  as  sf
-import time
+import PyMsOfa.python  as  sf
+
 
 def   line():
         print('-'*60)
